@@ -5,7 +5,7 @@
 /*
 
     This file is part of the extensible drawing editor Ipe.
-    Copyright (C) 1993-2012  Otfried Cheong
+    Copyright (c) 1993-2019 Otfried Cheong
 
     Ipe is free software; you can redistribute it and/or modify it
     under the terms of the GNU General Public License as published by
@@ -159,6 +159,9 @@ namespace ipe {
     inline Vector topLeft() const { return Vector(iMin.x, iMax.y); }
     //! Return bottom right corner.
     inline Vector bottomRight() const { return Vector(iMax.x, iMin.y); }
+    //! Return center of rectangle.
+    inline Vector center() const { return (iMin + iMax) * 0.5; }
+
     //! Return width.
     double width() const { return iMax.x - iMin.x; }
     //! Return height.
@@ -239,6 +242,8 @@ namespace ipe {
     bool snap(const Vector &v, double &t, Vector &pos, double &bound) const;
     static Bezier quadBezier(const Vector &p0, const Vector &p1,
 			     const Vector &p2);
+    static void oldSpline(int n,  const Vector *v,
+			  std::vector<Bezier> &result);
     static void spline(int n,  const Vector *v,
 		       std::vector<Bezier> &result);
     static void closedSpline(int n,  const Vector *v,
@@ -287,6 +292,7 @@ namespace ipe {
     inline Bezier operator*(const Bezier &rhs) const;
     inline Vector translation() const;
     inline Linear linear() const;
+    inline double determinant() const;
     inline bool isIdentity() const;
     inline bool operator==(const Matrix &rhs) const;
   public:
@@ -602,6 +608,12 @@ namespace ipe {
     return Vector(a[4], a[5]);
   }
 
+  //! Return determinant of the matrix.
+  inline double Matrix::determinant() const
+  {
+    return a[0]*a[3]-a[1]*a[2];
+  }
+
   //! Check for equality of two matrices.
   inline bool Matrix::operator==(const Matrix &rhs) const
   {
