@@ -56,6 +56,7 @@ namespace ipe {
       Color iSymFill;
       Fixed iSymPen;
       Fixed iOpacity;
+      Fixed iStrokeOpacity;
       Attribute iTiling;
       Attribute iGradient;
     };
@@ -98,6 +99,7 @@ namespace ipe {
     void setSymFill(Attribute color);
     void setSymPen(Attribute wid);
     void setOpacity(Attribute opaq);
+    void setStrokeOpacity(Attribute opaq);
     void setTiling(Attribute til);
     void setGradient(Attribute grad);
 
@@ -128,6 +130,8 @@ namespace ipe {
     inline Fixed symPen() const { return iState.back().iSymPen; }
     //! Return current opacity.
     inline Fixed opacity() const { return iState.back().iOpacity; }
+    //! Return current stroke opacity.
+    inline Fixed strokeOpacity() const { return iState.back().iStrokeOpacity; }
     //! Return current tiling.
     inline Attribute tiling() const { return iState.back().iTiling; }
     //! Return current gradient fill.
