@@ -298,6 +298,7 @@ function MODEL:showPathStylePopup(v)
 
   local opacities = sheet:allNames("opacity")
   m:add("opacity", "Opacity", opacities, nil, a.opacity)
+  m:add("strokeopacity", "Stroke opacity", opacities, nil, a.strokeopacity)
 
   local tilings = sheet:allNames("tiling")
   table.insert(tilings, 1, "normal")
@@ -739,12 +740,23 @@ function MODEL:compute_rect(w, h, res)
   return rect
 end
 
-function MODEL:action_export_png()
+function MODEL:export(format)
   local dir
   if self.file_name then dir = self.file_name:match(prefs.dir_pattern) end
   if not dir then dir = prefs.save_as_directory end
+  local title, filter
+  if format == "png" then
+    title = "Export to PNG"
+    filter = filter_png
+  elseif format == "eps" then
+    title = "Export to EPS"
+    filter = filter_eps
+  else
+    title = "Export to SVG"
+    filter = filter_svg
+  end
   local s, f =
-    ipeui.fileDialog(self.ui:win(), "save", "Export to PNG", filter_png, dir)
+    ipeui.fileDialog(self.ui:win(), "save", title, filter, dir)
   if s then
     if config.toolkit ~= "cocoa" and ipe.fileExists(s) then
       local b = messageBox(self.ui:win(), "question",
@@ -757,31 +769,21 @@ function MODEL:action_export_png()
       end
     end
     self.ui:renderPage(self.doc, self.pno, self.vno,
-		       "png", s, self.ui:zoom(),
+       		       format, s, self.ui:zoom(),
 		       true, false) -- transparent, nocrop
   end
 end
 
 function MODEL:action_export_eps()
-  local dir
-  if self.file_name then dir = self.file_name:match(prefs.dir_pattern) end
-  if not dir then dir = prefs.save_as_directory end
-  local s, f =
-    ipeui.fileDialog(self.ui:win(), "save", "Export to EPS", filter_eps, dir)
-  if s then
-    if config.toolkit ~= "cocoa" and ipe.fileExists(s) then
-      local b = messageBox(self.ui:win(), "question",
-			   "File already exists!",
-			   "Do you wish to overwrite?\n\n" .. s,
-			   "okcancel")
-      if b ~= 1 then
-	self.ui:explain("Document not exported")
-	return
-      end
-    end
-    self.ui:renderPage(self.doc, self.pno, self.vno,
-		       "eps", s, 1.0, false, false)
-  end
+  self:export("eps")
+end
+
+function MODEL:action_export_png()
+  self:export("png")
+end
+
+function MODEL:action_export_svg()
+  self:export("svg")
 end
 
 function MODEL:action_insert_image()
@@ -884,6 +886,25 @@ function MODEL:action_about_ipelets()
   action_about_ipelets(self.ui:win())
 end
 
+function MODEL:action_preferences()
+  local d = ipeui.Dialog(win, "Ipe: Preferences")
+  local s = "Ipe preferences are changed by creating a Lua source file.\n\n"
+  s = s .. "You can find the available options in 'prefs.lua', 'shortcuts.lua', and 'mouse.lua'"
+  s = s .. " (all on the path '" .. package.path .. "').\n\n"
+  s = s .. "Normally, you would not modify those files directly.\n\nInstead, create a new file '"
+  if config.platform == "win" then
+    s = s .. config.ipeletDirs[#config.ipeletDirs] .. "\\" .. "customization.lua"
+  else
+    s = s .. "~/.ipe/ipelets/customization.lua"
+  end
+  s = s .. "', place your changes in this file, and restart Ipe.\n\n"
+  s = s .. "For further details, please read the manual."
+  d:add("text", "text", { read_only=true }, 1, 1)
+  d:set("text", s)
+  d:addButton("ok", "Ok", "accept")
+  d:execute(prefs.latexlog_size)
+end
+
 function MODEL:action_keyboard()
   local s = prefs.keyboard
   if s then
@@ -928,6 +949,46 @@ function MODEL:action_developer_list_shortcuts()
   print(dupl, " duplicate shortcuts found")
 end
 
+function MODEL:action_cloud_latex()
+  local d = ipeui.Dialog(win, "Ipe: Latex in the cloud")
+  local urlFile = config.latexdir .. "url.txt"
+  if ipe.fileExists(urlFile) then
+    local f = ipe.openFile(urlFile, "r")
+    local url = f:read("a")
+    url = url:match("^(%S+)%s*$")
+    f:close()
+    d:add("label1", "label",
+	  { label="You are currently using the following online Latex-compilation service:" }, 1, 1, 1, 3)
+    d:add("url", "label", { label=url }, 2, 2)
+    d:add("label2", "label",
+	  { label="Please keep in mind that the contents of all your text objects "
+	    .. "is transmitted to this service at every Latex compilation." }, 3, 1, 1, 3)
+    d:add("label3", "label",
+	  { label = "You may not want to use online compilation for confidential information." }, 4, 1, 1, 3)
+    d:addButton("ok", "Disable online compilation", "accept")
+    d:addButton("cancel", "&Cancel", "reject")
+    if d:execute() then
+      os.remove(urlFile)
+    end
+  else
+    d:add("label1", "label",
+	  { label="Would you like to use the following online Latex-compilation service?" }, 1, 1, 1, 3)
+    d:add("url", "label", { label=prefs.latex_service_url }, 2, 2)
+    d:add("label2", "label",
+	  { label="Please keep in mind that the contents of all your text objects "
+	    .. "is transmitted to this service at every Latex compilation." }, 3, 1, 1, 3)
+    d:add("label3", "label",
+	  { label = "You may not want to use online compilation for confidential information." }, 4, 1, 1, 3)
+    d:addButton("ok", "Enable online compilation", "accept")
+    d:addButton("cancel", "&Cancel", "reject")
+    if d:execute() then
+      local f = ipe.openFile(urlFile, "w")
+      f:write(prefs.latex_service_url, "\n")
+      f:close()
+    end
+  end
+end
+
 ----------------------------------------------------------------------
 
 function MODEL:setOrigin(snapping)
@@ -1432,31 +1493,41 @@ function MODEL:action_delete_view()
   self.ui:explain(t.label)
 end
 
-function MODEL:action_edit_effects()
+function MODEL:action_edit_view()
   local p = self:page()
-  local effect = p:effect(self.vno)
+  local effect0 = p:effect(self.vno)
+  local name0 = p:viewName(self.vno)
   local list = self.doc:sheets():allNames("effect")
   table.insert(list, 1, "normal")
-  local d = ipeui.Dialog(self.ui:win(), "Edit view effect")
-  local label = "Choose effect for view " .. self.vno
-  d:add("label", "label", { label=label }, 1, 1)
-  d:add("combo", "combo", list, 0, 1)
+  local d = ipeui.Dialog(self.ui:win(), "Edit view")
+  local label = "View " .. self.vno .. " of " .. p:countViews()
+  d:add("label", "label", { label=label }, 1, 1, 2, 1)
+  d:add("name-label", "label", { label="Name" }, 0, 1)
+  d:add("name", "input", {}, -1, 2)
+  d:add("effect-label", "label", { label="Effect" }, 0, 1)
+  d:add("combo", "combo", list, -1, 2)
   d:addButton("ok", "&Ok", "accept")
   d:addButton("cancel", "&Cancel", "reject")
-  d:set("combo", indexOf(effect, list))
+  d:set("name", name0)
+  d:set("combo", indexOf(effect0, list))
   if not d:execute() then return end
-  local final = list[d:get("combo")]
-  local t = { label="set effect of view " .. self.vno .. " to " .. final,
+  local name1 = d:get("name")
+  local effect1 = list[d:get("combo")]
+  local t = { label="modify view " .. self.vno,
 	      pno = self.pno,
 	      vno = self.vno,
-	      original = effect,
-	      final = final,
+	      name0 = name0,
+	      effect0 = effect0,
+	      name1 = name1,
+	      effect1 = effect1,
 	    }
   t.undo = function (t, doc)
-	     p:setEffect(t.vno, t.original)
+	     p:setEffect(t.vno, t.effect0)
+	     p:setViewName(t.vno, t.name0)
 	   end
   t.redo = function (t, doc)
-	     p:setEffect(t.vno, t.final)
+	     p:setEffect(t.vno, t.effect1)
+	     p:setViewName(t.vno, t.name1)
 	   end
   self:register(t)
 end
@@ -2182,7 +2253,7 @@ function MODEL:action_update_style_sheets()
   local dir = nil
   if self.file_name then dir = string.gsub(self.file_name, "[^/\\]+$", "") end
   if dir == "" then dir = "." end
-  local sheets = self.doc:sheets()
+  local sheets = self.doc:sheets():clone()
   local qlog = ""
   for index=1,sheets:count() do
     local sheet = sheets:sheet(index)
@@ -2420,6 +2491,7 @@ function MODEL:action_document_properties()
   d:addButton("cancel", "&Cancel", "reject")
   d:setStretch("column", 5, 1)
   d:setStretch("row", 7, 1)
+  addEditorField(d, "preamble")
   for n in pairs(p) do d:set(n, p[n]) end
   if not d:execute() then return end
 
